<?php

namespace Drupal\forms_steps\Service;

/**
 * Class FormsStepsHelper.
 *
 * @package Drupal\forms_steps\Service
 */
class FormsStepsHelper {

  /**
   * FormsStepsManager.
   *
   * @var \Drupal\forms_steps\Service\FormsStepsManager
   */
  protected $formsStepsManager;

  /**
   * FormsStepsManager constructor.
   *
   * @param \Drupal\forms_steps\Service\FormsStepsManager $forms_steps_manager
   *   Injected FormsStepsManager instance.
   */
  public function __construct(FormsStepsManager $forms_steps_manager) {
    $this->formsStepsManager = $forms_steps_manager;
  }

  /**
   * Get the workflow instance ID if in a current forms steps route.
   *
   * @return false|string
   *   Return the Instance ID or FALSE otherwise.
   */
  public function getWorkflowInstanceIdFromRoute() {
    $route_match = \Drupal::routeMatch();

    $step = $this->formsStepsManager->getStepByRoute($route_match->getRouteName());

    // Only return the workflow instance id if the current route is a forms
    // steps route.
    if ($step) {
      $instanceId = $route_match->getParameter('instance_id');

      return $instanceId;
    }

    return FALSE;
  }

}
